@@ -10,21 +10,20 @@
 //!
 //! ## Getting started
 //! Most programs that interact with pipewire will need the same few basic objects:
-//! - A [`MainLoop`] that drives the program, reacting to any incoming events and dispatching method calls.
+//! - A [`MainLoop`](`main_loop::MainLoop`) that drives the program, reacting to any incoming events and dispatching method calls.
 //!   Most of a time, the program/thread will sit idle in this loop, waiting on events to occur.
-//! - A [`Context`] that keeps track of any pipewire resources.
-//! - A [`Core`] that is a proxy for the remote pipewire instance, used to send messages to and receive events from the
+//! - A [`Context`](`context::Context`) that keeps track of any pipewire resources.
+//! - A [`Core`](`core::Core`) that is a proxy for the remote pipewire instance, used to send messages to and receive events from the
 //!   remote server.
 //! - Optionally, a [`Registry`](`registry::Registry`) that can be used to manage and track available objects on the server.
 //!
 //! This is how they can be created:
-// ignored because https://gitlab.freedesktop.org/pipewire/pipewire-rs/-/issues/19
 //! ```no_run
-//! use pipewire::{MainLoop, Context};
+//! use pipewire::{main_loop::MainLoopBox, context::ContextBox};
 //!
 //! fn main() -> Result<(), Box<dyn std::error::Error>> {
-//!     let mainloop = MainLoop::new()?;
-//!     let context = Context::new(&mainloop)?;
+//!     let mainloop = MainLoopBox::new(None)?;
+//!     let context = ContextBox::new(&mainloop.loop_(), None)?;
 //!     let core = context.connect(None)?;
 //!     let registry = core.get_registry()?;
 //!
@@ -32,14 +31,37 @@
 //! }
 //! ```
 //!
-//! Now you can start hooking up different kinds of callbacks to the objects to react to events, and call methods
-//! on objects to change the state of the remote.
+//! The example above uses [`std::boxed::Box`]-like smart pointers to create the needed objects.
+//! Those boxes use lifetimes to ensure the objects dependencies (e.g. `Core` depends on `MainLoop`)
+//! outlive the object itself.
+//! If more flexibility is needed, [`std::rc::Rc`]-like reference-counting smart pointers also exist.
+//! Those will automatically keep the objects dependencies alive until the object is destroyed.
+//!
+//! Both of these kinds of types will automatically dereference to non-owning references for shared
+//! functionality, e.g. [`&MainLoop`](`main_loop::MainLoop`) or [`&Core`](`core::Core`).
+//!
+//! The same example as above, but using `Rc` types:
 //! ```no_run
-//! use pipewire::{MainLoop, Context};
+//! use pipewire::{main_loop::MainLoopRc, context::ContextRc};
 //!
 //! fn main() -> Result<(), Box<dyn std::error::Error>> {
-//!     let mainloop = MainLoop::new()?;
-//!     let context = Context::new(&mainloop)?;
+//!     let mainloop = MainLoopRc::new(None)?;
+//!     let context = ContextRc::new(&mainloop, None)?;
+//!     let core = context.connect_rc(None)?;
+//!     let registry = core.get_registry_rc()?;
+//!
+//!     Ok(())
+//! }
+//! ```
+//!
+//! Once the needed objects are created, you can start hooking up different kinds of callbacks to
+//! them to react to events, and call methods to change the state of the remote.
+//! ```no_run
+//! use pipewire::{main_loop::MainLoopBox, context::ContextBox};
+//!
+//! fn main() -> Result<(), Box<dyn std::error::Error>> {
+//!     let mainloop = MainLoopBox::new(None)?;
+//!     let context = ContextBox::new(&mainloop.loop_(), None)?;
 //!     let core = context.connect(None)?;
 //!     let registry = core.get_registry()?;
 //!
@@ -77,13 +99,13 @@
 //! For example, we can call a function on an interval:
 //!
 //! ```no_run
-//! use pipewire::MainLoop;
+//! use pipewire::main_loop::MainLoopBox;
 //! use std::time::Duration;
 //!
 //! fn main() -> Result<(), Box<dyn std::error::Error>> {
-//!     let mainloop = MainLoop::new()?;
+//!     let mainloop = MainLoopBox::new(None)?;
 //!
-//!     let timer = mainloop.add_timer(|_| println!("Hello"));
+//!     let timer = mainloop.loop_().add_timer(|_| println!("Hello"));
 //!     // Call the first time in half a second, and then in a one second interval.
 //!     timer.update_timer(Some(Duration::from_millis(500)), Some(Duration::from_secs(1))).into_result()?;
 //!
@@ -100,7 +122,7 @@
 //! The pipewire library is not really thread-safe, so pipewire objects do not implement [`Send`](`std::marker::Send`)
 //! or [`Sync`](`std::marker::Sync`).
 //!
-//! However, you can spawn a [`MainLoop`] in another thread and do bidirectional communication using two channels.
+//! However, you can spawn a [`MainLoop`](`main_loop::MainLoop`) in another thread and do bidirectional communication using two channels.
 //!
 //! To send messages to the main thread, we can easily use a [`std::sync::mpsc`].
 //! Because we are stuck in the main loop in the pipewire thread and can't just block on receiving a message,
@@ -108,42 +130,39 @@
 //!
 //! See the [`pipewire::channel`](`crate::channel`) module for details.
 
-use std::ptr;
-
-pub use context::*;
-pub use core_::*;
-pub use error::*;
-pub use loop_::*;
-pub use main_loop::*;
-pub use properties::*;
-pub use pw_sys as sys;
-pub use spa;
-
 pub mod buffer;
 pub mod channel;
+pub mod client;
 pub mod constants;
-mod context;
-mod core_;
-mod error;
+pub mod context;
+pub mod core;
+pub mod device;
+pub mod factory;
 pub mod keys;
 pub mod link;
-mod loop_;
-mod main_loop;
+pub mod loop_;
+pub mod main_loop;
 pub mod metadata;
+pub mod module;
 pub mod node;
+pub mod permissions;
 pub mod port;
-mod properties;
+pub mod properties;
 pub mod proxy;
 pub mod registry;
 pub mod stream;
+pub mod thread_loop;
 pub mod types;
+
+mod error;
+pub use error::*;
+
 mod utils;
 
-// Re-export all the traits in a prelude module, so that applications
-// can always "use pipewire::prelude::*" without getting conflicts
-pub mod prelude {
-    pub use spa::prelude::*;
-}
+pub use pw_sys as sys;
+pub use spa;
+
+use std::ptr;
 
 /// Initialize PipeWire
 ///
